==> prestashop_1.4.0.7.zip: prestashop/modules/statsdata/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsdata}prestashop>statsdata_a51950bf91ba55cd93a33ce3f8d448c2'] = 'Explotación de datos para las estadísticas';
$_MODULE['<{statsdata}prestashop>statsdata_7bf6ca30111df3fa9a2f915819628c1d'] = 'Este módulo debe estar activado si usted quiere utilizar las estadísticas';
$_MODULE['<{statsdata}prestashop>statsdata_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuración';
$_MODULE['<{statsdata}prestashop>statsdata_d54af676581940fc3e0658acccda7c38'] = 'Guardar las páginas vistas por cada cliente';
$_MODULE['<{statsdata}prestashop>statsdata_93cba07454f06a4a960172bbd6e2a435'] = 'Sí';
$_MODULE['<{statsdata}prestashop>statsdata_bafd7322c6e97d25b6299b5d6fe8920b'] = 'No';
$_MODULE['<{statsdata}prestashop>statsdata_5afa2e01daede51283baba1bee4d82e2'] = 'Las páginas vistas de los clientes consumen muchos recursos de procesador y espacio en la base de datos. ';
$_MODULE['<{statsdata}prestashop>statsdata_8d48af0cf690377bfbf8963f995fdf47'] = 'Guardar las páginas vistas globales';
$_MODULE['<{statsdata}prestashop>statsdata_9da6db806e64ef79cdcf2d4698d85ce2'] = 'Las páginas vistas necesitan menos recursos que el detalle por cliente, pero siguen necesitando bastantes.';
$_MODULE['<{statsdata}prestashop>statsdata_48f08588e7f264b5ea1e7ea56ed768f6'] = 'Detección de plug-ins';
$_MODULE['<{statsdata}prestashop>statsdata_baf9d6f7a4bfb4e238d2b12542712084'] = 'La detección de plug-ins carga un archivo javascript de 20ko suplementarios para los nuevos visitantes.';
$_MODULE['<{statsdata}prestashop>statsdata_06933067aafd48425d67bcb01bba5cb6'] = 'Actualizar';

==> prestashop_1.4.0.9.zip: prestashop/modules/statsdata/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{statsdata}prestashop>statsdata_a51950bf91ba55cd93a33ce3f8d448c2'] = 'Explotación de datos para las estadísticas';
$_MODULE['<{statsdata}prestashop>statsdata_7bf6ca30111df3fa9a2f915819628c1d'] = 'Este módulo debe estar activado si usted quiere utilizar las estadísticas';
$_MODULE['<{statsdata}prestashop>statsdata_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuración actualizada';
$_MODULE['<{statsdata}prestashop>statsdata_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuración';
$_MODULE['<{statsdata}prestashop>statsdata_d54af676581940fc3e0658acccda7c38'] = 'Guardar las páginas vistas por cada cliente';
$_MODULE['<{statsdata}prestashop>statsdata_93cba07454f06a4a960172bbd6e2a435'] = 'Sí';
$_MODULE['<{statsdata}prestashop>statsdata_bafd7322c6e97d25b6299b5d6fe8920b'] = 'No';
$_MODULE['<{statsdata}prestashop>statsdata_5afa2e01daede51283baba1bee4d82e2'] = 'Las páginas vistas de los clientes consumen muchos recursos de procesador y espacio en la base de datos. ';
$_MODULE['<{statsdata}prestashop>statsdata_8d48af0cf690377bfbf8963f995fdf47'] = 'Guardar las páginas vistas globales';
$_MODULE['<{statsdata}prestashop>statsdata_9da6db806e64ef79cdcf2d4698d85ce2'] = 'Las páginas vistas necesitan menos recursos que el detalle por cliente, pero siguen necesitando bastantes.';
$_MODULE['<{statsdata}prestashop>statsdata_48f08588e7f264b5ea1e7ea56ed768f6'] = 'Detección de plug-ins';
$_MODULE['<{statsdata}prestashop>statsdata_54e5f8bdd6c51a73d79ed702cdc9ac05'] = 'La detección de los plug-ins carga un archivo javascript de 20 ko suplementario para los nuevos visitantes.';
$_MODULE['<{statsdata}prestashop>statsdata_06933067aafd48425d67bcb01bba5cb6'] = 'Actualizar';
